	{ 0,	0,	printargs,		"svr4_syscall"	}, /*  000 */
	{ 0,	0,	printargs,		"svr4_exit"	}, /*  001 */
	{ 0,	0,	printargs,		"svr4_fork"	}, /*  002 */
	{ 0,	0,	printargs,		"svr4_read"	}, /*  003 */
	{ 0,	0,	printargs,		"svr4_write"	}, /*  004 */
	{ 0,	0,	printargs,		"svr4_open"	}, /*  005 */
	{ 0,	0,	printargs,		"svr4_close"	}, /*  006 */
	{ 0,	0,	printargs,		"svr4_wait"	}, /*  007 */
	{ 0,	0,	printargs,		"svr4_creat"	}, /*  008 */
	{ 0,	0,	printargs,		"svr4_link"	}, /*  009 */
	{ 0,	0,	printargs,		"svr4_unlink"	}, /*  010 */
	{ 0,	0,	printargs,		"svr4_exec"	}, /*  011 */
	{ 0,	0,	printargs,		"svr4_chdir"	}, /*  012 */
	{ 0,	0,	printargs,		"svr4_gtime"	}, /*  013 */
	{ 0,	0,	printargs,		"svr4_mknod"	}, /*  014 */
	{ 0,	0,	printargs,		"svr4_chmod"	}, /*  015 */
	{ 0,	0,	printargs,		"svr4_chown"	}, /*  016 */
	{ 0,	TM,	printargs,		"svr4_sbreak"	}, /*  017 */
	{ 0,	0,	printargs,		"svr4_stat"	}, /*  018 */
	{ 0,	0,	printargs,		"svr4_lseek"	}, /*  019 */
	{ 0,	0,	printargs,		"svr4_getpid"	}, /*  020 */
	{ 0,	0,	printargs,		"svr4_mount"	}, /*  021 */
	{ 0,	0,	printargs,		"svr4_umount"	}, /*  022 */
	{ 0,	0,	printargs,		"svr4_setuid"	}, /*  023 */
	{ 0,	0,	printargs,		"svr4_getuid"	}, /*  024 */
	{ 0,	0,	printargs,		"svr4_stime"	}, /*  025 */
	{ 0,	0,	printargs,		"svr4_ptrace"	}, /*  026 */
	{ 0,	0,	printargs,		"svr4_alarm"	}, /*  027 */
	{ 0,	0,	printargs,		"svr4_fstat"	}, /*  028 */
	{ 0,	0,	printargs,		"svr4_pause"	}, /*  029 */
	{ 0,	0,	printargs,		"svr4_utime"	}, /*  030 */
	{ 0,	0,	printargs,		"svr4_stty"	}, /*  031 */
	{ 0,	0,	printargs,		"svr4_gtty"	}, /*  032 */
	{ 0,	0,	printargs,		"svr4_access"	}, /*  033 */
	{ 0,	0,	printargs,		"svr4_nice"	}, /*  034 */
	{ 0,	0,	printargs,		"svr4_statfs"	}, /*  035 */
	{ 0,	0,	printargs,		"svr4_sync"	}, /*  036 */
	{ 0,	0,	printargs,		"svr4_kill"	}, /*  037 */
	{ 0,	0,	printargs,		"svr4_fstatfs"	}, /*  038 */
	{ 0,	0,	printargs,		"svr4_setpgrp"	}, /*  039 */
	{ 0,	0,	printargs,		"svr4_cxenix"	}, /*  040 */
	{ 0,	0,	printargs,		"svr4_dup"	}, /*  041 */
	{ 0,	0,	printargs,		"svr4_pipe"	}, /*  042 */
	{ 0,	0,	printargs,		"svr4_times"	}, /*  043 */
	{ 0,	0,	printargs,		"svr4_profil"	}, /*  044 */
	{ 0,	0,	printargs,		"svr4_plock"	}, /*  045 */
	{ 0,	0,	printargs,		"svr4_setgid"	}, /*  046 */
	{ 0,	0,	printargs,		"svr4_getgid"	}, /*  047 */
	{ 0,	0,	printargs,		"svr4_sig"	}, /*  048 */
	{ 0,	0,	printargs,		"svr4_msgsys"	}, /*  049 */
	{ 0,	0,	printargs,		"svr4_sysmips"	}, /*  050 */
	{ 0,	0,	printargs,		"svr4_sysacct"	}, /*  051 */
	{ 0,	0,	printargs,		"svr4_shmsys"	}, /*  052 */
	{ 0,	0,	printargs,		"svr4_semsys"	}, /*  053 */
	{ 0,	0,	printargs,		"svr4_ioctl"	}, /*  054 */
	{ 0,	0,	printargs,		"svr4_uadmin"	}, /*  055 */
	{ 0,	0,	printargs,		"svr4_exch"	}, /*  056 */
	{ 0,	0,	printargs,		"svr4_utssys"	}, /*  057 */
	{ 0,	0,	printargs,		"svr4_fsync"	}, /*  058 */
	{ 0,	0,	printargs,		"svr4_exece"	}, /*  059 */
	{ 0,	0,	printargs,		"svr4_umask"	}, /*  060 */
	{ 0,	0,	printargs,		"svr4_chroot"	}, /*  061 */
	{ 0,	0,	printargs,		"svr4_fcntl"	}, /*  062 */
	{ 0,	0,	printargs,		"svr4_ulimit"	}, /*  063 */
	{ 0,	0,	NULL,			NULL		}, /*  064 */
	{ 0,	0,	NULL,			NULL		}, /*  065 */
	{ 0,	0,	NULL,			NULL		}, /*  066 */
	{ 0,	0,	NULL,			NULL		}, /*  067 */
	{ 0,	0,	NULL,			NULL		}, /*  068 */
	{ 0,	0,	NULL,			NULL		}, /*  069 */
	{ 0,	0,	printargs,		"svr4_advfs"	}, /*  070 */
	{ 0,	0,	printargs,		"svr4_unadvfs"	}, /*  071 */
	{ 0,	0,	NULL,			NULL		}, /*  072 */
	{ 0,	0,	NULL,			NULL		}, /*  073 */
	{ 0,	0,	printargs,		"svr4_rfstart"	}, /*  074 */
	{ 0,	0,	NULL,			NULL		}, /*  075 */
	{ 0,	0,	printargs,		"svr4_rdebug"	}, /*  076 */
	{ 0,	0,	printargs,		"svr4_rfstop"	}, /*  077 */
	{ 0,	0,	printargs,		"svr4_rfsys"	}, /*  078 */
	{ 0,	0,	printargs,		"svr4_rmdir"	}, /*  079 */
	{ 0,	0,	printargs,		"svr4_mkdir"	}, /*  080 */
	{ 0,	0,	printargs,		"svr4_getdents"	}, /*  081 */
	{ 0,	0,	printargs,		"svr4_libattach"	}, /*  082 */
	{ 0,	0,	printargs,		"svr4_libdetach"	}, /*  083 */
	{ 0,	0,	printargs,		"svr4_sysfs"	}, /*  084 */
	{ 0,	0,	printargs,		"svr4_getmsg"	}, /*  085 */
	{ 0,	0,	printargs,		"svr4_putmsg"	}, /*  086 */
	{ 0,	0,	printargs,		"svr4_poll"	}, /*  087 */
	{ 0,	0,	printargs,		"svr4_lstat"	}, /*  088 */
	{ 0,	0,	printargs,		"svr4_symlink"	}, /*  089 */
	{ 0,	0,	printargs,		"svr4_readlink"	}, /*  090 */
	{ 0,	0,	printargs,		"svr4_setgroups"	}, /*  091 */
	{ 0,	0,	printargs,		"svr4_getgroups"	}, /*  092 */
	{ 0,	0,	printargs,		"svr4_fchmod"	}, /*  093 */
	{ 0,	0,	printargs,		"svr4_fchown"	}, /*  094 */
	{ 0,	0,	printargs,		"svr4_sigprocmask"	}, /*  095 */
	{ 0,	0,	printargs,		"svr4_sigsuspend"	}, /*  096 */
	{ 0,	0,	printargs,		"svr4_sigaltstack"	}, /*  097 */
	{ 0,	0,	printargs,		"svr4_sigaction"	}, /*  098 */
	{ 0,	0,	printargs,		"svr4_sigpending"	}, /*  099 */
	{ 0,	0,	printargs,		"svr4_setcontext"	}, /*  0100 */
	{ 0,	0,	printargs,		"svr4_evsys"	}, /*  0101 */
	{ 0,	0,	printargs,		"svr4_evtrapret"	}, /*  0102 */
	{ 0,	0,	printargs,		"svr4_statvfs"	}, /*  0103 */
	{ 0,	0,	printargs,		"svr4_fstatvfs"	}, /*  0104 */
	{ 0,	0,	NULL,			NULL		}, /* 105 */
	{ 0,	0,	printargs,		"svr4_nfssys"	}, /*  0106 */
	{ 0,	0,	printargs,		"svr4_waitid"	}, /*  0107 */
	{ 0,	0,	printargs,		"svr4_sigsendset"	}, /*  0108 */
	{ 0,	0,	printargs,		"svr4_hrtsys"	}, /*  0109 */
	{ 0,	0,	printargs,		"svr4_acancel"	}, /*  0110 */
	{ 0,	0,	printargs,		"svr4_async"	}, /*  0111 */
	{ 0,	0,	printargs,		"svr4_priocntlset"	}, /*  0112 */
	{ 0,	0,	printargs,		"svr4_pathconf"	}, /*  0113 */
	{ 0,	TM,	printargs,		"svr4_mincore"	}, /*  0114 */
	{ 0,	TD|TM|SI,	printargs,		"svr4_mmap"	}, /*  0115 */
	{ 0,	TM|SI,	printargs,		"svr4_mprotect"	}, /*  0116 */
	{ 0,	TM|SI,	printargs,		"svr4_munmap"	}, /*  0117 */
	{ 0,	0,	printargs,		"svr4_fpathconf"	}, /*  0118 */
	{ 0,	0,	printargs,		"svr4_vfork"	}, /*  0119 */
	{ 0,	0,	printargs,		"svr4_fchdir"	}, /*  0120 */
	{ 0,	0,	printargs,		"svr4_readv"	}, /*  0121 */
	{ 0,	0,	printargs,		"svr4_writev"	}, /*  0122 */
	{ 0,	0,	printargs,		"svr4_xstat"	}, /*  0123 */
	{ 0,	0,	printargs,		"svr4_lxstat"	}, /*  0124 */
	{ 0,	0,	printargs,		"svr4_fxstat"	}, /*  0125 */
	{ 0,	0,	printargs,		"svr4_xmknod"	}, /*  0126 */
	{ 0,	0,	printargs,		"svr4_clocal"	}, /*  0127 */
	{ 0,	0,	printargs,		"svr4_setrlimit"	}, /*  0128 */
	{ 0,	0,	printargs,		"svr4_getrlimit"	}, /*  0129 */
	{ 0,	0,	printargs,		"svr4_lchown"	}, /*  0130 */
	{ 0,	0,	printargs,		"svr4_memcntl"	}, /*  0131 */
	{ 0,	0,	printargs,		"svr4_getpmsg"	}, /*  0132 */
	{ 0,	0,	printargs,		"svr4_putpmsg"	}, /*  0133 */
	{ 0,	0,	printargs,		"svr4_rename"	}, /*  0134 */
	{ 0,	0,	printargs,		"svr4_nuname"	}, /*  0135 */
	{ 0,	0,	printargs,		"svr4_setegid"	}, /*  0136 */
	{ 0,	0,	printargs,		"svr4_sysconf"	}, /*  0137 */
	{ 0,	0,	printargs,		"svr4_adjtime"	}, /*  0138 */
	{ 0,	0,	printargs,		"svr4_sysinfo"	}, /*  0139 */
	{ 0,	0,	NULL,			NULL		}, /* 140 */
	{ 0,	0,	printargs,		"svr4_seteuid"	}, /*  0141 */
	{ 0,	0,	printargs,		"svr4_PYRAMID_statis"	}, /*  0142 */
	{ 0,	0,	printargs,		"svr4_PYRAMID_tuning"	}, /*  0143 */
	{ 0,	0,	printargs,		"svr4_PYRAMID_forcerr"	}, /*  0144 */
	{ 0,	0,	printargs,		"svr4_PYRAMID_mpcntl"	}, /*  0145 */
	{ 0,	0,	NULL,			NULL		}, /* 146 */
	{ 0,	0,	NULL,			NULL		}, /* 147 */
	{ 0,	0,	NULL,			NULL		}, /* 148 */
	{ 0,	0,	NULL,			NULL		}, /* 149 */
	{ 0,	0,	NULL,			NULL		}, /* 150 */
	{ 0,	0,	NULL,			NULL		}, /* 151 */
	{ 0,	0,	NULL,			NULL		}, /* 152 */
	{ 0,	0,	NULL,			NULL		}, /* 153 */
	{ 0,	0,	NULL,			NULL		}, /* 154 */
	{ 0,	0,	NULL,			NULL		}, /* 155 */
	{ 0,	0,	NULL,			NULL		}, /* 156 */
	{ 0,	0,	NULL,			NULL		}, /* 157 */
	{ 0,	0,	NULL,			NULL		}, /* 158 */
	{ 0,	0,	NULL,			NULL		}, /* 159 */
	{ 0,	0,	NULL,			NULL		}, /* 160 */
	{ 0,	0,	NULL,			NULL		}, /* 161 */
	{ 0,	0,	NULL,			NULL		}, /* 162 */
	{ 0,	0,	NULL,			NULL		}, /* 163 */
	{ 0,	0,	NULL,			NULL		}, /* 164 */
	{ 0,	0,	NULL,			NULL		}, /* 165 */
	{ 0,	0,	NULL,			NULL		}, /* 166 */
	{ 0,	0,	NULL,			NULL		}, /* 167 */
	{ 0,	0,	NULL,			NULL		}, /* 168 */
	{ 0,	0,	NULL,			NULL		}, /* 169 */
	{ 0,	0,	NULL,			NULL		}, /* 170 */
	{ 0,	0,	NULL,			NULL		}, /* 171 */
	{ 0,	0,	NULL,			NULL		}, /* 172 */
	{ 0,	0,	NULL,			NULL		}, /* 173 */
	{ 0,	0,	NULL,			NULL		}, /* 174 */
	{ 0,	0,	NULL,			NULL		}, /* 175 */
	{ 0,	0,	NULL,			NULL		}, /* 176 */
	{ 0,	0,	NULL,			NULL		}, /* 177 */
	{ 0,	0,	NULL,			NULL		}, /* 178 */
	{ 0,	0,	NULL,			NULL		}, /* 179 */
	{ 0,	0,	NULL,			NULL		}, /* 180 */
	{ 0,	0,	NULL,			NULL		}, /* 181 */
	{ 0,	0,	NULL,			NULL		}, /* 182 */
	{ 0,	0,	NULL,			NULL		}, /* 183 */
	{ 0,	0,	NULL,			NULL		}, /* 184 */
	{ 0,	0,	NULL,			NULL		}, /* 185 */
	{ 0,	0,	NULL,			NULL		}, /* 186 */
	{ 0,	0,	NULL,			NULL		}, /* 187 */
	{ 0,	0,	NULL,			NULL		}, /* 188 */
	{ 0,	0,	NULL,			NULL		}, /* 189 */
	{ 0,	0,	NULL,			NULL		}, /* 190 */
	{ 0,	0,	NULL,			NULL		}, /* 191 */
	{ 0,	0,	NULL,			NULL		}, /* 192 */
	{ 0,	0,	NULL,			NULL		}, /* 193 */
	{ 0,	0,	NULL,			NULL		}, /* 194 */
	{ 0,	0,	NULL,			NULL		}, /* 195 */
	{ 0,	0,	NULL,			NULL		}, /* 196 */
	{ 0,	0,	NULL,			NULL		}, /* 197 */
	{ 0,	0,	NULL,			NULL		}, /* 198 */
	{ 0,	0,	NULL,			NULL		}, /* 199 */
	{ 0,	0,	NULL,			NULL		}, /* 200 */
	{ 0,	0,	printargs,		"svr4_aread"	}, /*  0201 */
	{ 0,	0,	printargs,		"svr4_awrite"	}, /*  0202 */
	{ 0,	0,	printargs,		"svr4_listio"	}, /*  0203 */
	{ 0,	0,	printargs,		"svr4_mips_acancel"	}, /*  0204 */
	{ 0,	0,	printargs,		"svr4_astatus"	}, /*  0205 */
	{ 0,	0,	printargs,		"svr4_await"	}, /*  0206 */
	{ 0,	0,	printargs,		"svr4_areadv"	}, /*  0207 */
	{ 0,	0,	printargs,		"svr4_awritev"	}, /*  0208 */

	[209 ... 999] = { }, /*  999 */ /* end of SVR4 */

	{ 0,	0,	printargs,		"sysv_syscall"	}, /* 1000 */ /* start of SYSV */
	{ 0,	0,	printargs,		"sysv_exit"	}, /* 1001 */
	{ 0,	0,	printargs,		"sysv_fork"	}, /* 1002 */
	{ 0,	0,	printargs,		"sysv_read"	}, /* 1003 */
	{ 0,	0,	printargs,		"sysv_write"	}, /* 1004 */
	{ 0,	0,	printargs,		"sysv_open"	}, /* 1005 */
	{ 0,	0,	printargs,		"sysv_close"	}, /* 1006 */
	{ 0,	0,	printargs,		"sysv_wait"	}, /* 1007 */
	{ 0,	0,	printargs,		"sysv_creat"	}, /* 1008 */
	{ 0,	0,	printargs,		"sysv_link"	}, /* 1009 */
	{ 0,	0,	printargs,		"sysv_unlink"	}, /* 1010 */
	{ 0,	0,	printargs,		"sysv_execv"	}, /* 1011 */
	{ 0,	0,	printargs,		"sysv_chdir"	}, /* 1012 */
	{ 0,	0,	printargs,		"sysv_time"	}, /* 1013 */
	{ 0,	0,	printargs,		"sysv_mknod"	}, /* 1014 */
	{ 0,	0,	printargs,		"sysv_chmod"	}, /* 1015 */
	{ 0,	0,	printargs,		"sysv_chown"	}, /* 1016 */
	{ 0,	TM|SI,	printargs,		"sysv_brk"	}, /* 1017 */
	{ 0,	0,	printargs,		"sysv_stat"	}, /* 1018 */
	{ 0,	0,	printargs,		"sysv_lseek"	}, /* 1019 */
	{ 0,	0,	printargs,		"sysv_getpid"	}, /* 1020 */
	{ 0,	0,	printargs,		"sysv_mount"	}, /* 1021 */
	{ 0,	0,	printargs,		"sysv_umount"	}, /* 1022 */
	{ 0,	0,	printargs,		"sysv_setuid"	}, /* 1023 */
	{ 0,	0,	printargs,		"sysv_getuid"	}, /* 1024 */
	{ 0,	0,	printargs,		"sysv_stime"	}, /* 1025 */
	{ 0,	0,	printargs,		"sysv_ptrace"	}, /* 1026 */
	{ 0,	0,	printargs,		"sysv_alarm"	}, /* 1027 */
	{ 0,	0,	printargs,		"sysv_fstat"	}, /* 1028 */
	{ 0,	0,	printargs,		"sysv_pause"	}, /* 1029 */
	{ 0,	0,	printargs,		"sysv_utime"	}, /* 1030 */
	{ 0,	0,	printargs,		"sysv_stty"	}, /* 1031 */
	{ 0,	0,	printargs,		"sysv_gtty"	}, /* 1032 */
	{ 0,	0,	printargs,		"sysv_access"	}, /* 1033 */
	{ 0,	0,	printargs,		"sysv_nice"	}, /* 1034 */
	{ 0,	0,	printargs,		"sysv_statfs"	}, /* 1035 */
	{ 0,	0,	printargs,		"sysv_sync"	}, /* 1036 */
	{ 0,	0,	printargs,		"sysv_kill"	}, /* 1037 */
	{ 0,	0,	printargs,		"sysv_fstatfs"	}, /* 1038 */
	{ 0,	0,	printargs,		"sysv_setpgrp"	}, /* 1039 */
	{ 0,	0,	printargs,		"sysv_syssgi"	}, /* 1040 */
	{ 0,	0,	printargs,		"sysv_dup"	}, /* 1041 */
	{ 0,	0,	printargs,		"sysv_pipe"	}, /* 1042 */
	{ 0,	0,	printargs,		"sysv_times"	}, /* 1043 */
	{ 0,	0,	printargs,		"sysv_profil"	}, /* 1044 */
	{ 0,	0,	printargs,		"sysv_plock"	}, /* 1045 */
	{ 0,	0,	printargs,		"sysv_setgid"	}, /* 1046 */
	{ 0,	0,	printargs,		"sysv_getgid"	}, /* 1047 */
	{ 0,	0,	printargs,		"sysv_sig"	}, /* 1048 */
	{ 0,	0,	printargs,		"sysv_msgsys"	}, /* 1049 */
	{ 0,	0,	printargs,		"sysv_sysmips"	}, /* 1050 */
	{ 0,	0,	printargs,		"sysv_acct"	}, /* 1051 */
	{ 0,	0,	printargs,		"sysv_shmsys"	}, /* 1052 */
	{ 0,	0,	printargs,		"sysv_semsys"	}, /* 1053 */
	{ 0,	0,	printargs,		"sysv_ioctl"	}, /* 1054 */
	{ 0,	0,	printargs,		"sysv_uadmin"	}, /* 1055 */
	{ 0,	0,	printargs,		"sysv_sysmp"	}, /* 1056 */
	{ 0,	0,	printargs,		"sysv_utssys"	}, /* 1057 */
	{ 0,	0,	NULL,			NULL		}, /* 1058 */
	{ 0,	0,	printargs,		"sysv_execve"	}, /* 1059 */
	{ 0,	0,	printargs,		"sysv_umask"	}, /* 1060 */
	{ 0,	0,	printargs,		"sysv_chroot"	}, /* 1061 */
	{ 0,	0,	printargs,		"sysv_fcntl"	}, /* 1062 */
	{ 0,	0,	printargs,		"sysv_ulimit"	}, /* 1063 */
	{ 0,	0,	NULL,			NULL		}, /* 1064 */
	{ 0,	0,	NULL,			NULL		}, /* 1065 */
	{ 0,	0,	NULL,			NULL		}, /* 1066 */
	{ 0,	0,	NULL,			NULL		}, /* 1067 */
	{ 0,	0,	NULL,			NULL		}, /* 1068 */
	{ 0,	0,	NULL,			NULL		}, /* 1069 */
	{ 0,	0,	printargs,		"sysv_advfs"	}, /* 1070 */
	{ 0,	0,	printargs,		"sysv_unadvfs"	}, /* 1071 */
	{ 0,	0,	printargs,		"sysv_rmount"	}, /* 1072 */
	{ 0,	0,	printargs,		"sysv_rumount"	}, /* 1073 */
	{ 0,	0,	printargs,		"sysv_rfstart"	}, /* 1074 */
	{ 0,	0,	printargs,		"sysv_getrlimit64"	}, /* 1075 */
	{ 0,	0,	printargs,		"sysv_setrlimit64"	}, /* 1076 */
	{ 0,	0,	printargs,		"sysv_nanosleep"	}, /* 1077 */
	{ 0,	0,	printargs,		"sysv_lseek64"	}, /* 1078 */
	{ 0,	0,	printargs,		"sysv_rmdir"	}, /* 1079 */
	{ 0,	0,	printargs,		"sysv_mkdir"	}, /* 1080 */
	{ 0,	0,	printargs,		"sysv_getdents"	}, /* 1081 */
	{ 0,	0,	printargs,		"sysv_sginap"	}, /* 1082 */
	{ 0,	0,	printargs,		"sysv_sgikopt"	}, /* 1083 */
	{ 0,	0,	printargs,		"sysv_sysfs"	}, /* 1084 */
	{ 0,	0,	printargs,		"sysv_getmsg"	}, /* 1085 */
	{ 0,	0,	printargs,		"sysv_putmsg"	}, /* 1086 */
	{ 0,	0,	printargs,		"sysv_poll"	}, /* 1087 */
	{ 0,	0,	printargs,		"sysv_sigreturn"	}, /* 1088 */
	{ 0,	0,	printargs,		"sysv_accept"	}, /* 1089 */
	{ 0,	0,	printargs,		"sysv_bind"	}, /* 1090 */
	{ 0,	0,	printargs,		"sysv_connect"	}, /* 1091 */
	{ 0,	0,	printargs,		"sysv_gethostid"	}, /* 1092 */
	{ 0,	0,	printargs,		"sysv_getpeername"	}, /* 1093 */
	{ 0,	0,	printargs,		"sysv_getsockname"	}, /* 1094 */
	{ 0,	0,	printargs,		"sysv_getsockopt"	}, /* 1095 */
	{ 0,	0,	printargs,		"sysv_listen"	}, /* 1096 */
	{ 0,	0,	printargs,		"sysv_recv"	}, /* 1097 */
	{ 0,	0,	printargs,		"sysv_recvfrom"	}, /* 1098 */
	{ 0,	0,	printargs,		"sysv_recvmsg"	}, /* 1099 */
	{ 0,	0,	printargs,		"sysv_select"	}, /* 1100 */
	{ 0,	0,	printargs,		"sysv_send"	}, /* 1101 */
	{ 0,	0,	printargs,		"sysv_sendmsg"	}, /* 1102 */
	{ 0,	0,	printargs,		"sysv_sendto"	}, /* 1103 */
	{ 0,	0,	printargs,		"sysv_sethostid"	}, /* 1104 */
	{ 0,	0,	printargs,		"sysv_setsockopt"	}, /* 1105 */
	{ 0,	0,	printargs,		"sysv_shutdown"	}, /* 1106 */
	{ 0,	0,	printargs,		"sysv_socket"	}, /* 1107 */
	{ 0,	0,	printargs,		"sysv_gethostname"	}, /* 1108 */
	{ 0,	0,	printargs,		"sysv_sethostname"	}, /* 1109 */
	{ 0,	0,	printargs,		"sysv_getdomainname"	}, /* 1110 */
	{ 0,	0,	printargs,		"sysv_setdomainname"	}, /* 1111 */
	{ 0,	0,	printargs,		"sysv_truncate"	}, /* 1112 */
	{ 0,	0,	printargs,		"sysv_ftruncate"	}, /* 1113 */
	{ 0,	0,	printargs,		"sysv_rename"	}, /* 1114 */
	{ 0,	0,	printargs,		"sysv_symlink"	}, /* 1115 */
	{ 0,	0,	printargs,		"sysv_readlink"	}, /* 1116 */
	{ 0,	0,	printargs,		"sysv_lstat"	}, /* 1117 */
	{ 0,	0,	printargs,		"sysv_nfsmount"	}, /* 1118 */
	{ 0,	0,	printargs,		"sysv_nfssvc"	}, /* 1119 */
	{ 0,	0,	printargs,		"sysv_getfh"	}, /* 1120 */
	{ 0,	0,	printargs,		"sysv_async_daemon"	}, /* 1121 */
	{ 0,	0,	printargs,		"sysv_exportfs"	}, /* 1122 */
	{ 0,	0,	printargs,		"sysv_setregid"	}, /* 1123 */
	{ 0,	0,	printargs,		"sysv_setreuid"	}, /* 1124 */
	{ 0,	0,	printargs,		"sysv_getitimer"	}, /* 1125 */
	{ 0,	0,	printargs,		"sysv_setitimer"	}, /* 1126 */
	{ 0,	0,	printargs,		"sysv_adjtime"	}, /* 1127 */
	{ 0,	0,	printargs,		"sysv_BSD_getime"	}, /* 1128 */
	{ 0,	0,	printargs,		"sysv_sproc"	}, /* 1129 */
	{ 0,	0,	printargs,		"sysv_prctl"	}, /* 1130 */
	{ 0,	0,	printargs,		"sysv_procblk"	}, /* 1131 */
	{ 0,	0,	printargs,		"sysv_sprocsp"	}, /* 1132 */
	{ 0,	0,	printargs,		"sysv_sgigsc"	}, /* 1133 */
	{ 0,	TD|TM|SI,	printargs,		"sysv_mmap"	}, /* 1134 */
	{ 0,	TM|SI,	printargs,		"sysv_munmap"	}, /* 1135 */
	{ 0,	TM|SI,	printargs,		"sysv_mprotect"	}, /* 1136 */
	{ 0,	TM,	printargs,		"sysv_msync"	}, /* 1137 */
	{ 0,	TM,	printargs,		"sysv_madvise"	}, /* 1138 */
	{ 0,	0,	printargs,		"sysv_pagelock"	}, /* 1139 */
	{ 0,	0,	printargs,		"sysv_getpagesize"	}, /* 1140 */
	{ 0,	TF,	printargs,		"sysv_quotactl"	}, /* 1141 */
	{ 0,	0,	printargs,		"sysv_libdetach"	}, /* 1142 */
	{ 0,	0,	printargs,		"sysv_BSDgetpgrp"	}, /* 1143 */
	{ 0,	0,	printargs,		"sysv_BSDsetpgrp"	}, /* 1144 */
	{ 0,	0,	printargs,		"sysv_vhangup"	}, /* 1145 */
	{ 0,	0,	printargs,		"sysv_fsync"	}, /* 1146 */
	{ 0,	0,	printargs,		"sysv_fchdir"	}, /* 1147 */
	{ 0,	0,	printargs,		"sysv_getrlimit"	}, /* 1148 */
	{ 0,	0,	printargs,		"sysv_setrlimit"	}, /* 1149 */
	{ 0,	0,	printargs,		"sysv_cacheflush"	}, /* 1150 */
	{ 0,	0,	printargs,		"sysv_cachectl"	}, /* 1151 */
	{ 0,	0,	printargs,		"sysv_fchown"	}, /* 1152 */
	{ 0,	0,	printargs,		"sysv_fchmod"	}, /* 1153 */
	{ 0,	0,	printargs,		"sysv_wait3"	}, /* 1154 */
	{ 0,	0,	printargs,		"sysv_socketpair"	}, /* 1155 */
	{ 0,	0,	printargs,		"sysv_sysinfo"	}, /* 1156 */
	{ 0,	0,	printargs,		"sysv_nuname"	}, /* 1157 */
	{ 0,	0,	printargs,		"sysv_xstat"	}, /* 1158 */
	{ 0,	0,	printargs,		"sysv_lxstat"	}, /* 1159 */
	{ 0,	0,	printargs,		"sysv_fxstat"	}, /* 1160 */
	{ 0,	0,	printargs,		"sysv_xmknod"	}, /* 1161 */
	{ 0,	0,	printargs,		"sysv_ksigaction"	}, /* 1162 */
	{ 0,	0,	printargs,		"sysv_sigpending"	}, /* 1163 */
	{ 0,	0,	printargs,		"sysv_sigprocmask"	}, /* 1164 */
	{ 0,	0,	printargs,		"sysv_sigsuspend"	}, /* 1165 */
	{ 0,	0,	printargs,		"sysv_sigpoll"	}, /* 1166 */
	{ 0,	0,	printargs,		"sysv_swapctl"	}, /* 1167 */
	{ 0,	0,	printargs,		"sysv_getcontext"	}, /* 1168 */
	{ 0,	0,	printargs,		"sysv_setcontext"	}, /* 1169 */
	{ 0,	0,	printargs,		"sysv_waitsys"	}, /* 1170 */
	{ 0,	0,	printargs,		"sysv_sigstack"	}, /* 1171 */
	{ 0,	0,	printargs,		"sysv_sigaltstack"	}, /* 1172 */
	{ 0,	0,	printargs,		"sysv_sigsendset"	}, /* 1173 */
	{ 0,	0,	printargs,		"sysv_statvfs"	}, /* 1174 */
	{ 0,	0,	printargs,		"sysv_fstatvfs"	}, /* 1175 */
	{ 0,	0,	printargs,		"sysv_getpmsg"	}, /* 1176 */
	{ 0,	0,	printargs,		"sysv_putpmsg"	}, /* 1177 */
	{ 0,	0,	printargs,		"sysv_lchown"	}, /* 1178 */
	{ 0,	0,	printargs,		"sysv_priocntl"	}, /* 1179 */
	{ 0,	0,	printargs,		"sysv_ksigqueue"	}, /* 1180 */
	{ 0,	0,	printargs,		"sysv_readv"	}, /* 1181 */
	{ 0,	0,	printargs,		"sysv_writev"	}, /* 1182 */
	{ 0,	0,	printargs,		"sysv_truncate64"	}, /* 1183 */
	{ 0,	0,	printargs,		"sysv_ftruncate64"	}, /* 1184 */
	{ 0,	TD|TM|SI,	printargs,		"sysv_mmap64"	}, /* 1185 */
	{ 0,	0,	printargs,		"sysv_dmi"	}, /* 1186 */
	{ 0,	0,	printargs,		"sysv_pread"	}, /* 1187 */
	{ 0,	0,	printargs,		"sysv_pwrite"	}, /* 1188 */

	[1189 ... 1999] = { }, /* 1999 */ /* end of SYSV */

	{ 0,	0,	printargs,		"bsd43_syscall"	}, /* 2000 */ /* start of BSD 4.3 */
	{ 0,	0,	printargs,		"bsd43_exit"	}, /* 2001 */
	{ 0,	0,	printargs,		"bsd43_fork"	}, /* 2002 */
	{ 0,	0,	printargs,		"bsd43_read"	}, /* 2003 */
	{ 0,	0,	printargs,		"bsd43_write"	}, /* 2004 */
	{ 0,	0,	printargs,		"bsd43_open"	}, /* 2005 */
	{ 0,	0,	printargs,		"bsd43_close"	}, /* 2006 */
	{ 0,	0,	printargs,		"bsd43_wait"	}, /* 2007 */
	{ 0,	0,	printargs,		"bsd43_creat"	}, /* 2008 */
	{ 0,	0,	printargs,		"bsd43_link"	}, /* 2009 */
	{ 0,	0,	printargs,		"bsd43_unlink"	}, /* 2010 */
	{ 0,	0,	printargs,		"bsd43_exec"	}, /* 2011 */
	{ 0,	0,	printargs,		"bsd43_chdir"	}, /* 2012 */
	{ 0,	0,	printargs,		"bsd43_time"	}, /* 2013 */
	{ 0,	0,	printargs,		"bsd43_mknod"	}, /* 2014 */
	{ 0,	0,	printargs,		"bsd43_chmod"	}, /* 2015 */
	{ 0,	0,	printargs,		"bsd43_chown"	}, /* 2016 */
	{ 0,	TM,	printargs,		"bsd43_sbreak"	}, /* 2017 */
	{ 0,	0,	printargs,		"bsd43_oldstat"	}, /* 2018 */
	{ 0,	0,	printargs,		"bsd43_lseek"	}, /* 2019 */
	{ 0,	0,	printargs,		"bsd43_getpid"	}, /* 2020 */
	{ 0,	0,	printargs,		"bsd43_oldmount"	}, /* 2021 */
	{ 0,	0,	printargs,		"bsd43_umount"	}, /* 2022 */
	{ 0,	0,	printargs,		"bsd43_setuid"	}, /* 2023 */
	{ 0,	0,	printargs,		"bsd43_getuid"	}, /* 2024 */
	{ 0,	0,	printargs,		"bsd43_stime"	}, /* 2025 */
	{ 0,	0,	printargs,		"bsd43_ptrace"	}, /* 2026 */
	{ 0,	0,	printargs,		"bsd43_alarm"	}, /* 2027 */
	{ 0,	0,	printargs,		"bsd43_oldfstat"	}, /* 2028 */
	{ 0,	0,	printargs,		"bsd43_pause"	}, /* 2029 */
	{ 0,	0,	printargs,		"bsd43_utime"	}, /* 2030 */
	{ 0,	0,	printargs,		"bsd43_stty"	}, /* 2031 */
	{ 0,	0,	printargs,		"bsd43_gtty"	}, /* 2032 */
	{ 0,	0,	printargs,		"bsd43_access"	}, /* 2033 */
	{ 0,	0,	printargs,		"bsd43_nice"	}, /* 2034 */
	{ 0,	0,	printargs,		"bsd43_ftime"	}, /* 2035 */
	{ 0,	0,	printargs,		"bsd43_sync"	}, /* 2036 */
	{ 0,	0,	printargs,		"bsd43_kill"	}, /* 2037 */
	{ 0,	0,	printargs,		"bsd43_stat"	}, /* 2038 */
	{ 0,	0,	printargs,		"bsd43_oldsetpgrp"	}, /* 2039 */
	{ 0,	0,	printargs,		"bsd43_lstat"	}, /* 2040 */
	{ 0,	0,	printargs,		"bsd43_dup"	}, /* 2041 */
	{ 0,	0,	printargs,		"bsd43_pipe"	}, /* 2042 */
	{ 0,	0,	printargs,		"bsd43_times"	}, /* 2043 */
	{ 0,	0,	printargs,		"bsd43_profil"	}, /* 2044 */
	{ 0,	0,	printargs,		"bsd43_msgsys"	}, /* 2045 */
	{ 0,	0,	printargs,		"bsd43_setgid"	}, /* 2046 */
	{ 0,	0,	printargs,		"bsd43_getgid"	}, /* 2047 */
	{ 0,	0,	printargs,		"bsd43_ssig"	}, /* 2048 */
	{ 0,	0,	NULL,			NULL		}, /* 2049 */
	{ 0,	0,	NULL,			NULL		}, /* 2050 */
	{ 0,	0,	printargs,		"bsd43_sysacct"	}, /* 2051 */
	{ 0,	0,	printargs,		"bsd43_phys"	}, /* 2052 */
	{ 0,	0,	printargs,		"bsd43_lock"	}, /* 2053 */
	{ 0,	0,	printargs,		"bsd43_ioctl"	}, /* 2054 */
	{ 0,	0,	printargs,		"bsd43_reboot"	}, /* 2055 */
	{ 0,	0,	printargs,		"bsd43_mpxchan"	}, /* 2056 */
	{ 0,	0,	printargs,		"bsd43_symlink"	}, /* 2057 */
	{ 0,	0,	printargs,		"bsd43_readlink"	}, /* 2058 */
	{ 0,	0,	printargs,		"bsd43_execve"	}, /* 2059 */
	{ 0,	0,	printargs,		"bsd43_umask"	}, /* 2060 */
	{ 0,	0,	printargs,		"bsd43_chroot"	}, /* 2061 */
	{ 0,	0,	printargs,		"bsd43_fstat"	}, /* 2062 */
	{ 0,	0,	NULL,			NULL		}, /* 2063 */
	{ 0,	0,	printargs,		"bsd43_getpagesize"	}, /* 2064 */
	{ 0,	TM|SI,	printargs,		"bsd43_mremap"	}, /* 2065 */
	{ 0,	0,	printargs,		"bsd43_vfork"	}, /* 2066 */
	{ 0,	0,	printargs,		"bsd43_vread"	}, /* 2067 */
	{ 0,	0,	printargs,		"bsd43_vwrite"	}, /* 2068 */
	{ 0,	TM|SI,	printargs,		"bsd43_sbrk"	}, /* 2069 */
	{ 0,	0,	printargs,		"bsd43_sstk"	}, /* 2070 */
	{ 0,	TD|TM|SI,	printargs,		"bsd43_mmap"	}, /* 2071 */
	{ 0,	0,	printargs,		"bsd43_vadvise"	}, /* 2072 */
	{ 0,	TM|SI,	printargs,		"bsd43_munmap"	}, /* 2073 */
	{ 0,	TM|SI,	printargs,		"bsd43_mprotect"	}, /* 2074 */
	{ 0,	TM,	printargs,		"bsd43_madvise"	}, /* 2075 */
	{ 0,	0,	printargs,		"bsd43_vhangup"	}, /* 2076 */
	{ 0,	0,	printargs,		"bsd43_vlimit"	}, /* 2077 */
	{ 0,	TM,	printargs,		"bsd43_mincore"	}, /* 2078 */
	{ 0,	0,	printargs,		"bsd43_getgroups"	}, /* 2079 */
	{ 0,	0,	printargs,		"bsd43_setgroups"	}, /* 2080 */
	{ 0,	0,	printargs,		"bsd43_getpgrp"	}, /* 2081 */
	{ 0,	0,	printargs,		"bsd43_setpgrp"	}, /* 2082 */
	{ 0,	0,	printargs,		"bsd43_setitimer"	}, /* 2083 */
	{ 0,	0,	printargs,		"bsd43_wait3"	}, /* 2084 */
	{ 0,	0,	printargs,		"bsd43_swapon"	}, /* 2085 */
	{ 0,	0,	printargs,		"bsd43_getitimer"	}, /* 2086 */
	{ 0,	0,	printargs,		"bsd43_gethostname"	}, /* 2087 */
	{ 0,	0,	printargs,		"bsd43_sethostname"	}, /* 2088 */
	{ 0,	0,	printargs,		"bsd43_getdtablesize"	}, /* 2089 */
	{ 0,	0,	printargs,		"bsd43_dup2"	}, /* 2090 */
	{ 0,	0,	printargs,		"bsd43_getdopt"	}, /* 2091 */
	{ 0,	0,	printargs,		"bsd43_fcntl"	}, /* 2092 */
	{ 0,	0,	printargs,		"bsd43_select"	}, /* 2093 */
	{ 0,	0,	printargs,		"bsd43_setdopt"	}, /* 2094 */
	{ 0,	0,	printargs,		"bsd43_fsync"	}, /* 2095 */
	{ 0,	0,	printargs,		"bsd43_setpriority"	}, /* 2096 */
	{ 0,	0,	printargs,		"bsd43_socket"	}, /* 2097 */
	{ 0,	0,	printargs,		"bsd43_connect"	}, /* 2098 */
	{ 0,	0,	printargs,		"bsd43_oldaccept"	}, /* 2099 */
	{ 0,	0,	printargs,		"bsd43_getpriority"	}, /* 2100 */
	{ 0,	0,	printargs,		"bsd43_send"	}, /* 2101 */
	{ 0,	0,	printargs,		"bsd43_recv"	}, /* 2102 */
	{ 0,	0,	printargs,		"bsd43_sigreturn"	}, /* 2103 */
	{ 0,	0,	printargs,		"bsd43_bind"	}, /* 2104 */
	{ 0,	0,	printargs,		"bsd43_setsockopt"	}, /* 2105 */
	{ 0,	0,	printargs,		"bsd43_listen"	}, /* 2106 */
	{ 0,	0,	printargs,		"bsd43_vtimes"	}, /* 2107 */
	{ 0,	0,	printargs,		"bsd43_sigvec"	}, /* 2108 */
	{ 0,	0,	printargs,		"bsd43_sigblock"	}, /* 2109 */
	{ 0,	0,	printargs,		"bsd43_sigsetmask"	}, /* 2110 */
	{ 0,	0,	printargs,		"bsd43_sigpause"	}, /* 2111 */
	{ 0,	0,	printargs,		"bsd43_sigstack"	}, /* 2112 */
	{ 0,	0,	printargs,		"bsd43_oldrecvmsg"	}, /* 2113 */
	{ 0,	0,	printargs,		"bsd43_oldsendmsg"	}, /* 2114 */
	{ 0,	0,	printargs,		"bsd43_vtrace"	}, /* 2115 */
	{ 0,	0,	printargs,		"bsd43_gettimeofday"	}, /* 2116 */
	{ 0,	0,	printargs,		"bsd43_getrusage"	}, /* 2117 */
	{ 0,	0,	printargs,		"bsd43_getsockopt"	}, /* 2118 */
	{ 0,	0,	NULL,			NULL		}, /* 2119 */
	{ 0,	0,	printargs,		"bsd43_readv"	}, /* 2120 */
	{ 0,	0,	printargs,		"bsd43_writev"	}, /* 2121 */
	{ 0,	0,	printargs,		"bsd43_settimeofday"	}, /* 2122 */
	{ 0,	0,	printargs,		"bsd43_fchown"	}, /* 2123 */
	{ 0,	0,	printargs,		"bsd43_fchmod"	}, /* 2124 */
	{ 0,	0,	printargs,		"bsd43_oldrecvfrom"	}, /* 2125 */
	{ 0,	0,	printargs,		"bsd43_setreuid"	}, /* 2126 */
	{ 0,	0,	printargs,		"bsd43_setregid"	}, /* 2127 */
	{ 0,	0,	printargs,		"bsd43_rename"	}, /* 2128 */
	{ 0,	0,	printargs,		"bsd43_truncate"	}, /* 2129 */
	{ 0,	0,	printargs,		"bsd43_ftruncate"	}, /* 2130 */
	{ 0,	0,	printargs,		"bsd43_flock"	}, /* 2131 */
	{ 0,	0,	printargs,		"bsd43_semsys"	}, /* 2132 */
	{ 0,	0,	printargs,		"bsd43_sendto"	}, /* 2133 */
	{ 0,	0,	printargs,		"bsd43_shutdown"	}, /* 2134 */
	{ 0,	0,	printargs,		"bsd43_socketpair"	}, /* 2135 */
	{ 0,	0,	printargs,		"bsd43_mkdir"	}, /* 2136 */
	{ 0,	0,	printargs,		"bsd43_rmdir"	}, /* 2137 */
	{ 0,	0,	printargs,		"bsd43_utimes"	}, /* 2138 */
	{ 0,	0,	printargs,		"bsd43_sigcleanup"	}, /* 2139 */
	{ 0,	0,	printargs,		"bsd43_adjtime"	}, /* 2140 */
	{ 0,	0,	printargs,		"bsd43_oldgetpeername"	}, /* 2141 */
	{ 0,	0,	printargs,		"bsd43_gethostid"	}, /* 2142 */
	{ 0,	0,	printargs,		"bsd43_sethostid"	}, /* 2143 */
	{ 0,	0,	printargs,		"bsd43_getrlimit"	}, /* 2144 */
	{ 0,	0,	printargs,		"bsd43_setrlimit"	}, /* 2145 */
	{ 0,	0,	printargs,		"bsd43_killpg"	}, /* 2146 */
	{ 0,	0,	printargs,		"bsd43_shmsys"	}, /* 2147 */
	{ 0,	0,	printargs,		"bsd43_quota"	}, /* 2148 */
	{ 0,	0,	printargs,		"bsd43_qquota"	}, /* 2149 */
	{ 0,	0,	printargs,		"bsd43_oldgetsockname"	}, /* 2150 */
	{ 0,	0,	printargs,		"bsd43_sysmips"	}, /* 2151 */
	{ 0,	0,	printargs,		"bsd43_cacheflush"	}, /* 2152 */
	{ 0,	0,	printargs,		"bsd43_cachectl"	}, /* 2153 */
	{ 0,	0,	printargs,		"bsd43_debug"	}, /* 2154 */
	{ 0,	0,	NULL,			NULL		}, /* 2155 */
	{ 0,	0,	NULL,			NULL		}, /* 2156 */
	{ 0,	0,	printargs,		"bsd43_nfs_mount"	}, /* 2157 */
	{ 0,	0,	printargs,		"bsd43_nfs_svc"	}, /* 2158 */
	{ 0,	0,	printargs,		"bsd43_getdirentries"	}, /* 2159 */
	{ 0,	0,	printargs,		"bsd43_statfs"	}, /* 2160 */
	{ 0,	0,	printargs,		"bsd43_fstatfs"	}, /* 2161 */
	{ 0,	0,	printargs,		"bsd43_unmount"	}, /* 2162 */
	{ 0,	0,	printargs,		"bsd43_async_daemon"	}, /* 2163 */
	{ 0,	0,	printargs,		"bsd43_nfs_getfh"	}, /* 2164 */
	{ 0,	0,	printargs,		"bsd43_getdomainname"	}, /* 2165 */
	{ 0,	0,	printargs,		"bsd43_setdomainname"	}, /* 2166 */
	{ 0,	0,	printargs,		"bsd43_pcfs_mount"	}, /* 2167 */
	{ 0,	TF,	printargs,		"bsd43_quotactl"	}, /* 2168 */
	{ 0,	0,	printargs,		"bsd43_oldexportfs"	}, /* 2169 */
	{ 0,	0,	printargs,		"bsd43_smount"	}, /* 2170 */
	{ 0,	0,	printargs,		"bsd43_mipshwconf"	}, /* 2171 */
	{ 0,	0,	printargs,		"bsd43_exportfs"	}, /* 2172 */
	{ 0,	0,	printargs,		"bsd43_nfsfh_open"	}, /* 2173 */
	{ 0,	0,	printargs,		"bsd43_libattach"	}, /* 2174 */
	{ 0,	0,	printargs,		"bsd43_libdetach"	}, /* 2175 */
	{ 0,	0,	printargs,		"bsd43_accept"	}, /* 2176 */
	{ 0,	0,	NULL,			NULL		}, /* 2177 */
	{ 0,	0,	NULL,			NULL		}, /* 2178 */
	{ 0,	0,	printargs,		"bsd43_recvmsg"	}, /* 2179 */
	{ 0,	0,	printargs,		"bsd43_recvfrom"	}, /* 2180 */
	{ 0,	0,	printargs,		"bsd43_sendmsg"	}, /* 2181 */
	{ 0,	0,	printargs,		"bsd43_getpeername"	}, /* 2182 */
	{ 0,	0,	printargs,		"bsd43_getsockname"	}, /* 2183 */
	{ 0,	0,	printargs,		"bsd43_aread"	}, /* 2184 */
	{ 0,	0,	printargs,		"bsd43_awrite"	}, /* 2185 */
	{ 0,	0,	printargs,		"bsd43_listio"	}, /* 2186 */
	{ 0,	0,	printargs,		"bsd43_acancel"	}, /* 2187 */
	{ 0,	0,	printargs,		"bsd43_astatus"	}, /* 2188 */
	{ 0,	0,	printargs,		"bsd43_await"	}, /* 2189 */
	{ 0,	0,	printargs,		"bsd43_areadv"	}, /* 2190 */
	{ 0,	0,	printargs,		"bsd43_awritev"	}, /* 2191 */

	[2192 ... 2999] = { }, /* 2999 */ /* end of BSD 4.3 */

	{ 0,	0,	printargs,		"posix_syscall"	}, /* 3000 */ /* start of POSIX */
	{ 0,	0,	printargs,		"posix_exit"	}, /* 3001 */
	{ 0,	0,	printargs,		"posix_fork"	}, /* 3002 */
	{ 0,	0,	printargs,		"posix_read"	}, /* 3003 */
	{ 0,	0,	printargs,		"posix_write"	}, /* 3004 */
	{ 0,	0,	printargs,		"posix_open"	}, /* 3005 */
	{ 0,	0,	printargs,		"posix_close"	}, /* 3006 */
	{ 0,	0,	printargs,		"posix_wait"	}, /* 3007 */
	{ 0,	0,	printargs,		"posix_creat"	}, /* 3008 */
	{ 0,	0,	printargs,		"posix_link"	}, /* 3009 */
	{ 0,	0,	printargs,		"posix_unlink"	}, /* 3010 */
	{ 0,	0,	printargs,		"posix_exec"	}, /* 3011 */
	{ 0,	0,	printargs,		"posix_chdir"	}, /* 3012 */
	{ 0,	0,	printargs,		"posix_gtime"	}, /* 3013 */
	{ 0,	0,	printargs,		"posix_mknod"	}, /* 3014 */
	{ 0,	0,	printargs,		"posix_chmod"	}, /* 3015 */
	{ 0,	0,	printargs,		"posix_chown"	}, /* 3016 */
	{ 0,	TM,	printargs,		"posix_sbreak"	}, /* 3017 */
	{ 0,	0,	printargs,		"posix_stat"	}, /* 3018 */
	{ 0,	0,	printargs,		"posix_lseek"	}, /* 3019 */
	{ 0,	0,	printargs,		"posix_getpid"	}, /* 3020 */
	{ 0,	0,	printargs,		"posix_mount"	}, /* 3021 */
	{ 0,	0,	printargs,		"posix_umount"	}, /* 3022 */
	{ 0,	0,	printargs,		"posix_setuid"	}, /* 3023 */
	{ 0,	0,	printargs,		"posix_getuid"	}, /* 3024 */
	{ 0,	0,	printargs,		"posix_stime"	}, /* 3025 */
	{ 0,	0,	printargs,		"posix_ptrace"	}, /* 3026 */
	{ 0,	0,	printargs,		"posix_alarm"	}, /* 3027 */
	{ 0,	0,	printargs,		"posix_fstat"	}, /* 3028 */
	{ 0,	0,	printargs,		"posix_pause"	}, /* 3029 */
	{ 0,	0,	printargs,		"posix_utime"	}, /* 3030 */
	{ 0,	0,	printargs,		"posix_stty"	}, /* 3031 */
	{ 0,	0,	printargs,		"posix_gtty"	}, /* 3032 */
	{ 0,	0,	printargs,		"posix_access"	}, /* 3033 */
	{ 0,	0,	printargs,		"posix_nice"	}, /* 3034 */
	{ 0,	0,	printargs,		"posix_statfs"	}, /* 3035 */
	{ 0,	0,	printargs,		"posix_sync"	}, /* 3036 */
	{ 0,	0,	printargs,		"posix_kill"	}, /* 3037 */
	{ 0,	0,	printargs,		"posix_fstatfs"	}, /* 3038 */
	{ 0,	0,	printargs,		"posix_getpgrp"	}, /* 3039 */
	{ 0,	0,	printargs,		"posix_syssgi"	}, /* 3040 */
	{ 0,	0,	printargs,		"posix_dup"	}, /* 3041 */
	{ 0,	0,	printargs,		"posix_pipe"	}, /* 3042 */
	{ 0,	0,	printargs,		"posix_times"	}, /* 3043 */
	{ 0,	0,	printargs,		"posix_profil"	}, /* 3044 */
	{ 0,	0,	printargs,		"posix_lock"	}, /* 3045 */
	{ 0,	0,	printargs,		"posix_setgid"	}, /* 3046 */
	{ 0,	0,	printargs,		"posix_getgid"	}, /* 3047 */
	{ 0,	0,	printargs,		"posix_sig"	}, /* 3048 */
	{ 0,	0,	printargs,		"posix_msgsys"	}, /* 3049 */
	{ 0,	0,	printargs,		"posix_sysmips"	}, /* 3050 */
	{ 0,	0,	printargs,		"posix_sysacct"	}, /* 3051 */
	{ 0,	0,	printargs,		"posix_shmsys"	}, /* 3052 */
	{ 0,	0,	printargs,		"posix_semsys"	}, /* 3053 */
	{ 0,	0,	printargs,		"posix_ioctl"	}, /* 3054 */
	{ 0,	0,	printargs,		"posix_uadmin"	}, /* 3055 */
	{ 0,	0,	printargs,		"posix_exch"	}, /* 3056 */
	{ 0,	0,	printargs,		"posix_utssys"	}, /* 3057 */
	{ 0,	0,	NULL,			NULL		}, /* 3058 */
	{ 0,	0,	printargs,		"posix_exece"	}, /* 3059 */
	{ 0,	0,	printargs,		"posix_umask"	}, /* 3060 */
	{ 0,	0,	printargs,		"posix_chroot"	}, /* 3061 */
	{ 0,	0,	printargs,		"posix_fcntl"	}, /* 3062 */
	{ 0,	0,	printargs,		"posix_ulimit"	}, /* 3063 */
	{ 0,	0,	NULL,			NULL		}, /* 3064 */
	{ 0,	0,	NULL,			NULL		}, /* 3065 */
	{ 0,	0,	NULL,			NULL		}, /* 3066 */
	{ 0,	0,	NULL,			NULL		}, /* 3067 */
	{ 0,	0,	NULL,			NULL		}, /* 3068 */
	{ 0,	0,	NULL,			NULL		}, /* 3069 */
	{ 0,	0,	printargs,		"posix_advfs"	}, /* 3070 */
	{ 0,	0,	printargs,		"posix_unadvfs"	}, /* 3071 */
	{ 0,	0,	printargs,		"posix_rmount"	}, /* 3072 */
	{ 0,	0,	printargs,		"posix_rumount"	}, /* 3073 */
	{ 0,	0,	printargs,		"posix_rfstart"	}, /* 3074 */
	{ 0,	0,	NULL,			NULL		}, /* 3075 */
	{ 0,	0,	printargs,		"posix_rdebug"	}, /* 3076 */
	{ 0,	0,	printargs,		"posix_rfstop"	}, /* 3077 */
	{ 0,	0,	printargs,		"posix_rfsys"	}, /* 3078 */
	{ 0,	0,	printargs,		"posix_rmdir"	}, /* 3079 */
	{ 0,	0,	printargs,		"posix_mkdir"	}, /* 3080 */
	{ 0,	0,	printargs,		"posix_getdents"	}, /* 3081 */
	{ 0,	0,	printargs,		"posix_sginap"	}, /* 3082 */
	{ 0,	0,	printargs,		"posix_sgikopt"	}, /* 3083 */
	{ 0,	0,	printargs,		"posix_sysfs"	}, /* 3084 */
	{ 0,	0,	printargs,		"posix_getmsg"	}, /* 3085 */
	{ 0,	0,	printargs,		"posix_putmsg"	}, /* 3086 */
	{ 0,	0,	printargs,		"posix_poll"	}, /* 3087 */
	{ 0,	0,	printargs,		"posix_sigreturn"	}, /* 3088 */
	{ 0,	0,	printargs,		"posix_accept"	}, /* 3089 */
	{ 0,	0,	printargs,		"posix_bind"	}, /* 3090 */
	{ 0,	0,	printargs,		"posix_connect"	}, /* 3091 */
	{ 0,	0,	printargs,		"posix_gethostid"	}, /* 3092 */
	{ 0,	0,	printargs,		"posix_getpeername"	}, /* 3093 */
	{ 0,	0,	printargs,		"posix_getsockname"	}, /* 3094 */
	{ 0,	0,	printargs,		"posix_getsockopt"	}, /* 3095 */
	{ 0,	0,	printargs,		"posix_listen"	}, /* 3096 */
	{ 0,	0,	printargs,		"posix_recv"	}, /* 3097 */
	{ 0,	0,	printargs,		"posix_recvfrom"	}, /* 3098 */
	{ 0,	0,	printargs,		"posix_recvmsg"	}, /* 3099 */
	{ 0,	0,	printargs,		"posix_select"	}, /* 3100 */
	{ 0,	0,	printargs,		"posix_send"	}, /* 3101 */
	{ 0,	0,	printargs,		"posix_sendmsg"	}, /* 3102 */
	{ 0,	0,	printargs,		"posix_sendto"	}, /* 3103 */
	{ 0,	0,	printargs,		"posix_sethostid"	}, /* 3104 */
	{ 0,	0,	printargs,		"posix_setsockopt"	}, /* 3105 */
	{ 0,	0,	printargs,		"posix_shutdown"	}, /* 3106 */
	{ 0,	0,	printargs,		"posix_socket"	}, /* 3107 */
	{ 0,	0,	printargs,		"posix_gethostname"	}, /* 3108 */
	{ 0,	0,	printargs,		"posix_sethostname"	}, /* 3109 */
	{ 0,	0,	printargs,		"posix_getdomainname"	}, /* 3110 */
	{ 0,	0,	printargs,		"posix_setdomainname"	}, /* 3111 */
	{ 0,	0,	printargs,		"posix_truncate"	}, /* 3112 */
	{ 0,	0,	printargs,		"posix_ftruncate"	}, /* 3113 */
	{ 0,	0,	printargs,		"posix_rename"	}, /* 3114 */
	{ 0,	0,	printargs,		"posix_symlink"	}, /* 3115 */
	{ 0,	0,	printargs,		"posix_readlink"	}, /* 3116 */
	{ 0,	0,	printargs,		"posix_lstat"	}, /* 3117 */
	{ 0,	0,	printargs,		"posix_nfs_mount"	}, /* 3118 */
	{ 0,	0,	printargs,		"posix_nfs_svc"	}, /* 3119 */
	{ 0,	0,	printargs,		"posix_nfs_getfh"	}, /* 3120 */
	{ 0,	0,	printargs,		"posix_async_daemon"	}, /* 3121 */
	{ 0,	0,	printargs,		"posix_exportfs"	}, /* 3122 */
	{ 0,	0,	printargs,		"posix_SGI_setregid"	}, /* 3123 */
	{ 0,	0,	printargs,		"posix_SGI_setreuid"	}, /* 3124 */
	{ 0,	0,	printargs,		"posix_getitimer"	}, /* 3125 */
	{ 0,	0,	printargs,		"posix_setitimer"	}, /* 3126 */
	{ 0,	0,	printargs,		"posix_adjtime"	}, /* 3127 */
	{ 0,	0,	printargs,		"posix_SGI_bsdgettime"	}, /* 3128 */
	{ 0,	0,	printargs,		"posix_SGI_sproc"	}, /* 3129 */
	{ 0,	0,	printargs,		"posix_SGI_prctl"	}, /* 3130 */
	{ 0,	0,	printargs,		"posix_SGI_blkproc"	}, /* 3131 */
	{ 0,	0,	NULL,			NULL		}, /* 3132 */
	{ 0,	0,	printargs,		"posix_SGI_sgigsc"	}, /* 3133 */
	{ 0,	TD|TM|SI,	printargs,		"posix_SGI_mmap"	}, /* 3134 */
	{ 0,	TM|SI,	printargs,		"posix_SGI_munmap"	}, /* 3135 */
	{ 0,	TM|SI,	printargs,		"posix_SGI_mprotect"	}, /* 3136 */
	{ 0,	TM,	printargs,		"posix_SGI_msync"	}, /* 3137 */
	{ 0,	TM,	printargs,		"posix_SGI_madvise"	}, /* 3138 */
	{ 0,	0,	printargs,		"posix_SGI_mpin"	}, /* 3139 */
	{ 0,	0,	printargs,		"posix_SGI_getpagesize"	}, /* 3140 */
	{ 0,	0,	printargs,		"posix_SGI_libattach"	}, /* 3141 */
	{ 0,	0,	printargs,		"posix_SGI_libdetach"	}, /* 3142 */
	{ 0,	0,	printargs,		"posix_SGI_getpgrp"	}, /* 3143 */
	{ 0,	0,	printargs,		"posix_SGI_setpgrp"	}, /* 3144 */
	{ 0,	0,	NULL,			NULL		}, /* 3145 */
	{ 0,	0,	NULL,			NULL		}, /* 3146 */
	{ 0,	0,	NULL,			NULL		}, /* 3147 */
	{ 0,	0,	NULL,			NULL		}, /* 3148 */
	{ 0,	0,	NULL,			NULL		}, /* 3149 */
	{ 0,	0,	printargs,		"posix_cacheflush"	}, /* 3150 */
	{ 0,	0,	printargs,		"posix_cachectl"	}, /* 3151 */
	{ 0,	0,	printargs,		"posix_fchown"	}, /* 3152 */
	{ 0,	0,	printargs,		"posix_fchmod"	}, /* 3153 */
	{ 0,	0,	printargs,		"posix_wait3"	}, /* 3154 */
	{ 0,	TD|TM|SI,	printargs,		"posix_mmap"	}, /* 3155 */
	{ 0,	TM|SI,	printargs,		"posix_munmap"	}, /* 3156 */
	{ 0,	TM,	printargs,		"posix_madvise"	}, /* 3157 */
	{ 0,	0,	printargs,		"posix_BSD_getpagesize"	}, /* 3158 */
	{ 0,	0,	printargs,		"posix_setreuid"	}, /* 3159 */
	{ 0,	0,	printargs,		"posix_setregid"	}, /* 3160 */
	{ 0,	0,	printargs,		"posix_setpgid"	}, /* 3161 */
	{ 0,	0,	printargs,		"posix_getgroups"	}, /* 3162 */
	{ 0,	0,	printargs,		"posix_setgroups"	}, /* 3163 */
	{ 0,	0,	printargs,		"posix_gettimeofday"	}, /* 3164 */
	{ 0,	0,	printargs,		"posix_getrusage"	}, /* 3165 */
	{ 0,	0,	printargs,		"posix_getrlimit"	}, /* 3166 */
	{ 0,	0,	printargs,		"posix_setrlimit"	}, /* 3167 */
	{ 0,	0,	printargs,		"posix_waitpid"	}, /* 3168 */
	{ 0,	0,	printargs,		"posix_dup2"	}, /* 3169 */
	{ 0,	0,	NULL,			NULL		}, /* 3170 */
	{ 0,	0,	NULL,			NULL		}, /* 3171 */
	{ 0,	0,	NULL,			NULL		}, /* 3172 */
	{ 0,	0,	NULL,			NULL		}, /* 3173 */
	{ 0,	0,	NULL,			NULL		}, /* 3174 */
	{ 0,	0,	NULL,			NULL		}, /* 3175 */
	{ 0,	0,	NULL,			NULL		}, /* 3176 */
	{ 0,	0,	NULL,			NULL		}, /* 3177 */
	{ 0,	0,	NULL,			NULL		}, /* 3178 */
	{ 0,	0,	NULL,			NULL		}, /* 3179 */
	{ 0,	0,	NULL,			NULL		}, /* 3180 */
	{ 0,	0,	NULL,			NULL		}, /* 3181 */
	{ 0,	0,	NULL,			NULL		}, /* 3182 */
	{ 0,	0,	NULL,			NULL		}, /* 3183 */
	{ 0,	0,	NULL,			NULL		}, /* 3184 */
	{ 0,	0,	NULL,			NULL		}, /* 3185 */
	{ 0,	0,	NULL,			NULL		}, /* 3186 */
	{ 0,	0,	NULL,			NULL		}, /* 3187 */
	{ 0,	0,	NULL,			NULL		}, /* 3188 */
	{ 0,	0,	NULL,			NULL		}, /* 3189 */
	{ 0,	0,	NULL,			NULL		}, /* 3190 */
	{ 0,	0,	NULL,			NULL		}, /* 3191 */
	{ 0,	0,	NULL,			NULL		}, /* 3192 */
	{ 0,	0,	NULL,			NULL		}, /* 3193 */
	{ 0,	0,	NULL,			NULL		}, /* 3194 */
	{ 0,	0,	NULL,			NULL		}, /* 3195 */
	{ 0,	0,	NULL,			NULL		}, /* 3196 */
	{ 0,	0,	NULL,			NULL		}, /* 3197 */
	{ 0,	0,	NULL,			NULL		}, /* 3198 */
	{ 0,	0,	NULL,			NULL		}, /* 3199 */
	{ 0,	0,	NULL,			NULL		}, /* 3200 */
	{ 0,	0,	NULL,			NULL		}, /* 3201 */
	{ 0,	0,	NULL,			NULL		}, /* 3202 */
	{ 0,	0,	NULL,			NULL		}, /* 3203 */
	{ 0,	0,	NULL,			NULL		}, /* 3204 */
	{ 0,	0,	NULL,			NULL		}, /* 3205 */
	{ 0,	0,	NULL,			NULL		}, /* 3206 */
	{ 0,	0,	NULL,			NULL		}, /* 3207 */
	{ 0,	0,	NULL,			NULL		}, /* 3208 */
	{ 0,	0,	NULL,			NULL		}, /* 3209 */
	{ 0,	0,	NULL,			NULL		}, /* 3210 */
	{ 0,	0,	NULL,			NULL		}, /* 3211 */
	{ 0,	0,	NULL,			NULL		}, /* 3212 */
	{ 0,	0,	NULL,			NULL		}, /* 3213 */
	{ 0,	0,	NULL,			NULL		}, /* 3214 */
	{ 0,	0,	NULL,			NULL		}, /* 3215 */
	{ 0,	0,	NULL,			NULL		}, /* 3216 */
	{ 0,	0,	NULL,			NULL		}, /* 3217 */
	{ 0,	0,	NULL,			NULL		}, /* 3218 */
	{ 0,	0,	NULL,			NULL		}, /* 3219 */
	{ 0,	0,	NULL,			NULL		}, /* 3220 */
	{ 0,	0,	NULL,			NULL		}, /* 3221 */
	{ 0,	0,	NULL,			NULL		}, /* 3222 */
	{ 0,	0,	NULL,			NULL		}, /* 3223 */
	{ 0,	0,	NULL,			NULL		}, /* 3224 */
	{ 0,	0,	NULL,			NULL		}, /* 3225 */
	{ 0,	0,	NULL,			NULL		}, /* 3226 */
	{ 0,	0,	NULL,			NULL		}, /* 3227 */
	{ 0,	0,	NULL,			NULL		}, /* 3228 */
	{ 0,	0,	NULL,			NULL		}, /* 3229 */
	{ 0,	0,	NULL,			NULL		}, /* 3230 */
	{ 0,	0,	NULL,			NULL		}, /* 3231 */
	{ 0,	0,	NULL,			NULL		}, /* 3232 */
	{ 0,	0,	NULL,			NULL		}, /* 3233 */
	{ 0,	0,	NULL,			NULL		}, /* 3234 */
	{ 0,	0,	NULL,			NULL		}, /* 3235 */
	{ 0,	0,	NULL,			NULL		}, /* 3236 */
	{ 0,	0,	NULL,			NULL		}, /* 3237 */
	{ 0,	0,	NULL,			NULL		}, /* 3238 */
	{ 0,	0,	NULL,			NULL		}, /* 3239 */
	{ 0,	0,	NULL,			NULL		}, /* 3240 */
	{ 0,	0,	NULL,			NULL		}, /* 3241 */
	{ 0,	0,	NULL,			NULL		}, /* 3242 */
	{ 0,	0,	NULL,			NULL		}, /* 3243 */
	{ 0,	0,	NULL,			NULL		}, /* 3244 */
	{ 0,	0,	NULL,			NULL		}, /* 3245 */
	{ 0,	0,	NULL,			NULL		}, /* 3246 */
	{ 0,	0,	NULL,			NULL		}, /* 3247 */
	{ 0,	0,	NULL,			NULL		}, /* 3248 */
	{ 0,	0,	NULL,			NULL		}, /* 3249 */
	{ 0,	0,	NULL,			NULL		}, /* 3250 */
	{ 0,	0,	NULL,			NULL		}, /* 3251 */
	{ 0,	0,	NULL,			NULL		}, /* 3252 */
	{ 0,	0,	NULL,			NULL		}, /* 3253 */
	{ 0,	0,	NULL,			NULL		}, /* 3254 */
	{ 0,	0,	NULL,			NULL		}, /* 3255 */
	{ 0,	0,	NULL,			NULL		}, /* 3256 */
	{ 0,	0,	NULL,			NULL		}, /* 3257 */
	{ 0,	0,	NULL,			NULL		}, /* 3258 */
	{ 0,	0,	NULL,			NULL		}, /* 3259 */
	{ 0,	0,	printargs,		"posix_netboot"	}, /* 3260 */
	{ 0,	0,	printargs,		"posix_netunboot"	}, /* 3261 */
	{ 0,	0,	printargs,		"posix_rdump"	}, /* 3262 */
	{ 0,	0,	printargs,		"posix_setsid"	}, /* 3263 */
	{ 0,	0,	printargs,		"posix_getmaxsig"	}, /* 3264 */
	{ 0,	0,	printargs,		"posix_sigpending"	}, /* 3265 */
	{ 0,	0,	printargs,		"posix_sigprocmask"	}, /* 3266 */
	{ 0,	0,	printargs,		"posix_sigsuspend"	}, /* 3267 */
	{ 0,	0,	printargs,		"posix_sigaction"	}, /* 3268 */

	[3269 ... 3999] = { }, /* 3999 */ /* end of POSIX */
